==> qtjambi-help-5.15-sources.jar: io/qt/help/QHelpContentWidget.java <==
package io.qt.help;


/**
 * <p>Tree view for displaying help content model items</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qhelpcontentwidget.html">QHelpContentWidget</a></p>
 */
public final class QHelpContentWidget extends io.qt.widgets.QTreeView
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpContentWidget.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpcontentwidget.html#linkActivated">QHelpContentWidget::linkActivated(QUrl)</a></p>
     */
    public final Signal1<io.qt.core.QUrl> linkActivated = new Signal1<>();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpcontentwidget.html#indexOf">QHelpContentWidget::indexOf(QUrl)</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QModelIndex indexOf(io.qt.core.QUrl link){
        return indexOf_native_cref_QUrl(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(link));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QModelIndex indexOf_native_cref_QUrl(long __this__nativeId, long link);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpContentWidget(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-help-6.2.7-sources.jar: io/qt/help/QHelpContentWidget.java <==
package io.qt.help;


/**
 * <p>Tree view for displaying help content model items</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qhelpcontentwidget.html">QHelpContentWidget</a></p>
 */
public final class QHelpContentWidget extends io.qt.widgets.QTreeView
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpContentWidget.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpcontentwidget.html#linkActivated">QHelpContentWidget::linkActivated(QUrl)</a></p>
     */
    public final Signal1<io.qt.core.QUrl> linkActivated = new Signal1<>();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpcontentwidget.html#indexOf">QHelpContentWidget::indexOf(QUrl)</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QModelIndex indexOf(io.qt.core.QUrl link){
        return indexOf_native_cref_QUrl(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(link));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QModelIndex indexOf_native_cref_QUrl(long __this__nativeId, long link);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpContentWidget(QPrivateConstructor p) { super(p); } 
    
}
